Struct XdgToplevelIconManagerV1
pub struct XdgToplevelIconManagerV1 { /* private fields */ }wayland and Linux only.Expand description
interface to manage toplevel icons
This interface allows clients to create toplevel window icons and set them on toplevel windows to be displayed to the user.
See also the Request enum for this interface.
Implementations
impl XdgToplevelIconManagerV1
impl XdgToplevelIconManagerV1
pub fn icon_size(&self, size: i32)
pub fn icon_size(&self, size: i32)
describes a supported & preferred icon size
This event indicates an icon size the compositor prefers to be available if the client has scalable icons and can render to any size.
When the ‘xdg_toplevel_icon_manager_v1’ object is created, the compositor may send one or more ‘icon_size’ events to describe the list of preferred icon sizes. If the compositor has no size preference, it may not send any ‘icon_size’ event, and it is up to the client to decide a suitable icon size.
A sequence of ‘icon_size’ events must be finished with a ‘done’ event. If the compositor has no size preferences, it must still send the ‘done’ event, without any preceding ‘icon_size’ events.
pub fn done(&self)
pub fn done(&self)
all information has been sent
This event is sent after all ‘icon_size’ events have been sent.